@@ -3,6 +3,7 @@ from pathlib import Path
 from pydantic import Extra
 from pydantic_yaml import YamlModel
 import logging
+import os
 import tempfile
 import click
 import re
@@ -33,8 +34,8 @@ class Assignment(YamlModel):
             "examples": [
                 {
                     "description": "Oefening for lus",
-                    "path": "oefeningen/TypeScript/oefening-for-lus.md",
-                    "attachments": ["oefeningen/TypeScript/screenshot-for-lus.png"],
+                    "path": "/oefeningen/TypeScript/oefening-for-lus.md",
+                    "attachments": ["/oefeningen/TypeScript/screenshot-for-lus.png"],
                 }
             ]
         }
@@ -164,9 +165,11 @@ def writeschema() -> None:
 
 
 @click.command()
+@click.argument("assignments_path", type=click.Path(exists=True), nargs=1)
 @click.argument("paths", type=click.Path(exists=True), nargs=-1)
-def validate_module(paths) -> None:
+def validate_module(assignments_path, paths) -> None:
     """Run sanity checks on the graph structure and contents of a complete module."""
+    assignments_path = Path(assignments_path)
     messages: list[str] = []
     module = Module(clusters=[])
     for path in paths:
@@ -230,6 +233,10 @@ def validate_module(paths) -> None:
                         messages.append(
                             f"Path {assignment_path} mentioned in file {path} for node {node.id} does not exist!"
                         )
+                    elif assignments_path not in assignment_path.parents:
+                        messages.append(
+                            f"Path {assignment_path} does not extend {assignments_path}!"
+                        )
                     if assignment.attachments:
                         for attachment in assignment.attachments:
                             if attachment.is_absolute():
@@ -240,6 +247,10 @@ def validate_module(paths) -> None:
                                 messages.append(
                                     f"Path {locatable_attachment} mentioned in file {path} for node {node.id} as an attachment to assignment {assignment.description} does not exist!"
                                 )
+                            elif assignments_path not in locatable_attachment.parents:
+                                messages.append(
+                                    f"Path {locatable_attachment} does not extend {assignments_path}!"
+                                )
     # printing out messages first time here
     # reason is because malformed graph may cause issues
     for message in messages:
@@ -447,36 +458,43 @@ def _retain_edges(graph, kind: Literal["dependency"] | Literal["motivation"]):
 
 
 @click.command()
+@click.argument("assignments_path", type=click.Path(exists=True), nargs=1)
 @click.argument("cluster_paths", type=click.Path(exists=True), nargs=-1)
-def generate_moodle_structure(cluster_paths: list[Path]) -> None:
-    """Generates JSON data for the Moodle plugin."""
+def generate_moodle_structure(assignments_path: Path, cluster_paths: list[Path]) -> None:
+    """Generates JSON data for the Moodle plugin.
+    
+    Assumes the module has been validated."""
+    assignments_path = Path(assignments_path)
     module = Module(clusters=[])
     for path in cluster_paths:
         module.clusters.append(Cluster.parse_file(path))
     dag = _module_dependency_graph(module)  # includes both kinds
     dependency_graph = _retain_edges(dag, "dependency")
     motivation_graph = _retain_edges(dag, "motivation")
-    nodes_in_structure: Dict = dict()
+    assignments_path_start = assignments_path
+    collected_nodes = []
     for node in dag:
-        nodes_in_structure[node.id] = dict()
+        current_node = dict()
+        current_node['id'] = node.id
         if node.title:
-            nodes_in_structure[node.id]["title"] = node.title
+            current_node["title"] = node.title
         if node.assignments:
-            nodes_in_structure[node.id]["assignments"] = []
+            current_node["assignments"] = []
             for assignment in node.assignments:
                 list_element = {
                     "description": assignment.description,
-                    "path": str(assignment.path),
+                    "path": "/" + str(assignments_path_start.joinpath(assignment.path.relative_to(assignments_path))),
                 }
                 if assignment.attachments:
-                    list_element["attachments"] = list((str(path) for path in assignment.attachments))
-                nodes_in_structure[node.id]["assignments"].append(list_element)
+                    list_element["attachments"] = list(("/" + str(assignments_path_start.joinpath(path.relative_to(assignments_path))) for path in assignment.attachments))
+                current_node["assignments"].append(list_element)
         if node.urls:
-            nodes_in_structure[node.id]["URLs"] = []
+            current_node["URLs"] = []
             for URL in node.urls:
-                nodes_in_structure[node.id]["URLs"].append(
+                current_node["URLs"].append(
                     {"url": URL.url, "description": URL.description}
                 )
+        collected_nodes.append(current_node)
     enablers: Dict = dict()
     for node in dag.nodes():
         self_and_dependents: Set[Node] = nx.descendants(dependency_graph, node).union(
@@ -490,7 +508,7 @@ def generate_moodle_structure(cluster_paths: list[Path]) -> None:
                     current_node_enablers.append(non_dependent.id)
         enablers[node.id] = current_node_enablers
     structure: Dict = {
-        "nodes": nodes_in_structure,
+        "nodes": collected_nodes,
         # deliberately only adding *immediate* predecessors to avoid redundancy
         "requires_all_of": {
             node.id: [
